pub enum EdgeEvent<NI> {
AddStart(NodeSocket<NI>),
Add {
start: NodeSocket<NI>,
end: NodeSocket<NI>,
},
Cancelled(NodeSocket<NI>),
Remove {
start: NodeSocket<NI>,
end: NodeSocket<NI>,
},
}Expand description
Events related to adding and removing edges.
Variants
AddStart(NodeSocket<NI>)
The user has pressed the given node socket with the left mouse button to begin creating an edge.
Add
The user has attempted to create an edge between the two given node sockets.
Cancelled(NodeSocket<NI>)
The user has cancelled creating an edge from the given socket.
Remove
The user has attempted to remove the edge connecting the two given sockets.