pub struct CommonStyle {
pub maybe_x_dimension: Option<Dimension>,
pub maybe_y_dimension: Option<Dimension>,
pub maybe_x_position: Option<Position>,
pub maybe_y_position: Option<Position>,
pub maybe_depth: Option<Depth>,
}Expand description
Styling and positioning data that is common between all widget types.
Fields
maybe_x_dimension: Option<Dimension>The width of a Widget.
maybe_y_dimension: Option<Dimension>The height of a Widget.
maybe_x_position: Option<Position>The position of a Widget along the x axis.
maybe_y_position: Option<Position>The position of a Widget along the y axis.
maybe_depth: Option<Depth>The rendering Depth of the Widget.